/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class JiraServiceManagementCloudApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Customer = new CustomerGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Info = new InfoGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Assets = new AssetsGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Knowledgebase = new KnowledgebaseGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Organization = new OrganizationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Servicedesk = new ServicedeskGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Request = new RequestGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Customer, this.Info, this.Assets, this.Knowledgebase, this.Organization, this.Servicedesk, this.Request);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Customer, Info, Assets, Knowledgebase, Organization, Servicedesk, Request) {
        this.Customer = Customer;
        this.Info = Info;
        this.Assets = Assets;
        this.Knowledgebase = Knowledgebase;
        this.Organization = Organization;
        this.Servicedesk = Servicedesk;
        this.Request = Request;
    }
    /**
  * This method adds a customer to the Jira Service Management instance by passing a JSON file including an email address and display name. The display name does not need to be unique. The record's identifiers, `name` and `key`, are automatically generated from the request details.
  
  **[Permissions](#permissions) required**: Jira Administrator Global permission
  * Alternative usage: Customer.createCustomer
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-customer/#api-rest-servicedeskapi-customer-post
  * @param options Request options.
  */
    async createCustomer(options) {
        return this.Customer.createCustomer(options);
    }
    /**
  * This method retrieves information about the Jira Service Management instance such as software version, builds, and related links.
  
  **[Permissions](#permissions) required**: None, the user does not need to be logged in.
  * Alternative usage: Info.getInfo
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-info/#api-rest-servicedeskapi-info-get
  * @param options Request options.
  */
    async getInfo(options) {
        return this.Info.getInfo(options);
    }
    /**
  * Returns a list of Assets workspace IDs. Include a workspace ID in the path to access the [Assets REST APIs](https://developer.atlassian.com/cloud/assets/rest).
  
  **[Permissions](#permissions) required**: Any
  * Alternative usage: Assets.getWorkspaces
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-assets/#api-rest-servicedeskapi-assets-workspace-get
  * @param options Request options.
  */
    async getAssetsWorkspaces(options) {
        return this.Assets.getWorkspaces(options);
    }
    /**
  * Returns articles which match the given query string across all service desks.
  
  **[Permissions](#permissions) required**: Permission to access the [customer portal](https://confluence.atlassian.com/servicedeskcloud/configuring-the-customer-portal-732528918.html).
  * Alternative usage: Knowledgebase.getArticles
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-knowledgebase/#api-rest-servicedeskapi-knowledgebase-article-get
  * @param options Request options.
  */
    async getKnowledgebaseArticles(options) {
        return this.Knowledgebase.getArticles(options);
    }
    /**
  * This method returns a list of organizations in the Jira Service Management instance. Use this method when you want to present a list of organizations or want to locate an organization by name.
  
  **[Permissions](#permissions) required**: Any. However, to fetch organizations based on `accountId` the user must have a Service Desk agent license.
  
  **Response limitations**: If the user is a customer, only those organizations of which the customer is a member are listed.
  * Alternative usage: Organization.getOrganizations
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-get
  * @param options Request options.
  */
    async getOrganizations(options) {
        return this.Organization.getOrganizations(options);
    }
    /**
  * This method creates an organization by passing the name of the organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent. Note: Permission to create organizations can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Alternative usage: Organization.createOrganization
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-post
  * @param options Request options.
  */
    async createOrganization(options) {
        return this.Organization.createOrganization(options);
    }
    /**
  * This method returns details of an organization. Use this method to get organization details whenever your application component is passed an organization ID but needs to display other organization details.
  
  **[Permissions](#permissions) required**: Any
  
  **Response limitations**: Customers can only retrieve organization of which they are members.
  * Alternative usage: Organization.getOrganization
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-get
  * @param options Request options.
  */
    async getOrganization(options) {
        return this.Organization.getOrganization(options);
    }
    /**
  * This method deletes an organization. Note that the organization is deleted regardless of other associations it may have. For example, associations with service desks.
  
  **[Permissions](#permissions) required**: Jira administrator.
  * Alternative usage: Organization.deleteOrganization
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-delete
  * @param options Request options.
  */
    async deleteOrganization(options) {
        return this.Organization.deleteOrganization(options);
    }
    /**
  * Returns the keys of all properties for an organization. Use this resource when you need to find out what additional properties items have been added to an organization.
  
  **[Permissions](#permissions) required**: Any
  
  **Response limitations**: Customers can only access properties of organizations of which they are members.
  * Alternative usage: Organization.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-get
  * @param options Request options.
  */
    async getOrganizationPropertyKeys(options) {
        return this.Organization.Property.getKeys(options);
    }
    /**
  * Returns the value of a property from an organization. Use this method to obtain the JSON content for an organization's property.
  
  **[Permissions](#permissions) required**: Any
  
  **Response limitations**: Customers can only access properties of organizations of which they are members.
  * Alternative usage: Organization.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-propertykey-get
  * @param options Request options.
  */
    async getOrganizationProperty(options) {
        return this.Organization.Property.getProperty(options);
    }
    /**
  * Sets the value of a property for an organization. Use this resource to store custom data against an organization.
  
  **[Permissions](#permissions) required**: Service Desk Administrator or Agent.
  
  Note: Permission to manage organizations can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Alternative usage: Organization.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-propertykey-put
  * @param options Request options.
  */
    async setOrganizationProperty(options) {
        return this.Organization.Property.setProperty(options);
    }
    /**
  * Removes a property from an organization.
  
  **[Permissions](#permissions) required**: Service Desk Administrator or Agent.
  
  Note: Permission to manage organizations can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Alternative usage: Organization.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-propertykey-delete
  * @param options Request options.
  */
    async deleteOrganizationProperty(options) {
        return this.Organization.Property.deleteProperty(options);
    }
    /**
  * This method returns all the users associated with an organization. Use this method where you want to provide a list of users for an organization or determine if a user is associated with an organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent.
  * Alternative usage: Organization.User.getUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-user-get
  * @param options Request options.
  */
    async getOrganizationUsers(options) {
        return this.Organization.User.getUsers(options);
    }
    /**
  * This method adds users to an organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent. Note: Permission to add users to an organization can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Alternative usage: Organization.User.addUser
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-user-post
  * @param options Request options.
  */
    async addOrganizationUser(options) {
        return this.Organization.User.addUser(options);
    }
    /**
  * This method removes users from an organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent. Note: Permission to delete users from an organization can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Alternative usage: Organization.User.removeUser
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-user-delete
  * @param options Request options.
  */
    async removeOrganizationUser(options) {
        return this.Organization.User.removeUser(options);
    }
    /**
  * This method returns all the service desks in the Jira Service Management instance that the user has permission to access. Use this method where you need a list of service desks or need to locate a service desk by name or keyword.
  
  **[Permissions](#permissions) required**: Any
  * Alternative usage: Servicedesk.getServicedesks
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-get
  * @param options Request options.
  */
    async getServicedesks(options) {
        return this.Servicedesk.getServicedesks(options);
    }
    /**
  * This method returns a service desk. Use this method to get service desk details whenever your application component is passed a service desk ID but needs to display other service desk details.
  
  **[Permissions](#permissions) required**: Permission to access the Service Desk. For example, being the Service Desk's Administrator or one of its Agents or Users.
  * Alternative usage: Servicedesk.getServicedesk
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-get
  * @param options Request options.
  */
    async getServicedesk(options) {
        return this.Servicedesk.getServicedesk(options);
    }
    /**
  * This method adds one or more temporary attachments to a service desk, which can then be permanently attached to a customer request using [servicedeskapi/request/\{issueIdOrKey\}/attachment](#api-request-issueIdOrKey-attachment-post).
  
  **Note**: It is possible for a service desk administrator to turn off the ability to add attachments to a service desk.
  
  This method expects a multipart request. The media-type multipart/form-data is defined in RFC 1867. Most client libraries have classes that make dealing with multipart posts simple. For instance, in Java the Apache HTTP Components library provides [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html).
  
  Because this method accepts multipart/form-data, it has XSRF protection on it. This means you must submit a header of X-Atlassian-Token: no-check with the request or it will be blocked.
  
  The name of the multipart/form-data parameter that contains the attachments must be `file`.
  
  For example, to upload a file called `myfile.txt` in the Service Desk with ID 10001 use
  
      curl -D- -u customer:customer -X POST -H "X-ExperimentalApi: opt-in" -H "X-Atlassian-Token: no-check" -F "file=@myfile.txt" https://your-domain.atlassian.net/rest/servicedeskapi/servicedesk/10001/attachTemporaryFile
  
  **[Permissions](#permissions) required**: Permission to add attachments in this Service Desk.
  * Alternative usage: Servicedesk.addTemporaryFilesToServicedesk
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-attachtemporaryfile-post
  * @param options Request options.
  */
    async addTemporaryFilesToServicedesk(options) {
        return this.Servicedesk.addTemporaryFilesToServicedesk(options);
    }
    /**
  * This method returns a list of all organizations associated with a service desk.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Alternative usage: Servicedesk.Organization.getOrganizations
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-servicedesk-servicedeskid-organization-get
  * @param options Request options.
  */
    async getServicedeskOrganizations(options) {
        return this.Servicedesk.Organization.getOrganizations(options);
    }
    /**
  * This method adds an organization to a service desk. If the organization ID is already associated with the service desk, no change is made and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Alternative usage: Servicedesk.Organization.addOrganization
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-servicedesk-servicedeskid-organization-post
  * @param options Request options.
  */
    async addServicedeskOrganization(options) {
        return this.Servicedesk.Organization.addOrganization(options);
    }
    /**
  * This method removes an organization from a service desk. If the organization ID does not match an organization associated with the service desk, no change is made and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Alternative usage: Servicedesk.Organization.removeOrganization
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-servicedesk-servicedeskid-organization-delete
  * @param options Request options.
  */
    async removeServicedeskOrganization(options) {
        return this.Servicedesk.Organization.removeOrganization(options);
    }
    /**
  * This method returns a list of the customers on a service desk.
  
  The returned list of customers can be filtered using the `query` parameter. The parameter is matched against customers' `displayName`, `name`, or `email`. For example, searching for "John", "Jo", "Smi", or "Smith" will match a user with display name "John Smith".
  
  **[Permissions](#permissions) required**: Permission to view this Service Desk's customers.
  * Alternative usage: Servicedesk.Customer.getCustomers
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-customer-get
  * @param options Request options.
  */
    async getServicedeskCustomers(options) {
        return this.Servicedesk.Customer.getCustomers(options);
    }
    /**
  * Adds one or more customers to a service desk. If any of the passed customers are associated with the service desk, no changes will be made for those customers and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Service desk administrator
  * Alternative usage: Servicedesk.Customer.addCustomers
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-customer-post
  * @param options Request options.
  */
    async addServicedeskCustomers(options) {
        return this.Servicedesk.Customer.addCustomers(options);
    }
    /**
  * This method removes one or more customers from a service desk. The service desk must have closed access. If any of the passed customers are not associated with the service desk, no changes will be made for those customers and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Services desk administrator
  * Alternative usage: Servicedesk.Customer.removeCustomers
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-customer-delete
  * @param options Request options.
  */
    async removeServicedeskCustomers(options) {
        return this.Servicedesk.Customer.removeCustomers(options);
    }
    /**
  * Returns articles which match the given query and belong to the knowledge base linked to the service desk.
  
  **[Permissions](#permissions) required**: Permission to access the service desk.
  * Alternative usage: Servicedesk.Knowledgebase.getArticles
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-knowledgebase-article-get
  * @param options Request options.
  */
    async getServicedeskKnowledgebaseArticles(options) {
        return this.Servicedesk.Knowledgebase.getArticles(options);
    }
    /**
  * This method returns the queues in a service desk. To include a customer request count for each queue (in the `issueCount` field) in the response, set the query parameter `includeCount` to true (its default is false).
  
  **[Permissions](#permissions) required**: service desk's Agent.
  * Alternative usage: Servicedesk.Queue.getQueues
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-queue-get
  * @param options Request options.
  */
    async getServicedeskQueues(options) {
        return this.Servicedesk.Queue.getQueues(options);
    }
    /**
  * This method returns a specific queues in a service desk. To include a customer request count for the queue (in the `issueCount` field) in the response, set the query parameter `includeCount` to true (its default is false).
  
  **[Permissions](#permissions) required**: service desk's Agent.
  * Alternative usage: Servicedesk.Queue.getQueue
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-queue-queueid-get
  * @param options Request options.
  */
    async getServicedeskQueue(options) {
        return this.Servicedesk.Queue.getQueue(options);
    }
    /**
  * This method returns the customer requests in a queue. Only fields that the queue is configured to show are returned. For example, if a queue is configured to show description and due date, then only those two fields are returned for each customer request in the queue.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Alternative usage: Servicedesk.Queue.getIssuesInQueue
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-queue-queueid-issue-get
  * @param options Request options.
  */
    async getServicedeskIssuesInQueue(options) {
        return this.Servicedesk.Queue.getIssuesInQueue(options);
    }
    /**
  * This method returns all customer request types from a service desk. There are two parameters for filtering the returned list:
  
   *  `groupId` which filters the results to items in the customer request type group.
   *  `searchQuery` which is matched against request types' `name` or `description`. For example, the strings "Install", "Inst", "Equi", or "Equipment" will match a request type with the *name* "Equipment Installation Request".
  
  **[Permissions](#permissions) required**: Permission to access the service desk.
  * Alternative usage: Servicedesk.Request.Type.getTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-get
  * @param options Request options.
  */
    async getServicedeskRequestTypes(options) {
        return this.Servicedesk.Request.Type.getTypes(options);
    }
    /**
  * This method enables a customer request type to be added to a service desk based on an issue type. Note that not all customer request type fields can be specified in the request and these fields are given the following default values:
  
   *  Request type icon is given the headset icon.
   *  Request type groups is left empty, which means this customer request type will not be visible on the [customer portal](https://confluence.atlassian.com/servicedeskcloud/configuring-the-customer-portal-732528918.html).
   *  Request type status mapping is left empty, so the request type has no custom status mapping but inherits the status map from the issue type upon which it is based.
   *  Request type field mapping is set to show the required fields as specified by the issue type used to create the customer request type.
  
    
  These fields can be updated by a service desk administrator using the **Request types** option in **Project settings**.
  Request Types are created in next-gen projects by creating Issue Types. Please use the Jira Cloud Platform Create issue type endpoint instead.
  
  **[Permissions](#permissions) required**: Service desk's administrator
  * Alternative usage: Servicedesk.Request.Type.createType
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-post
  * @param options Request options.
  */
    async createServicedeskRequestType(options) {
        return this.Servicedesk.Request.Type.createType(options);
    }
    /**
  * This method returns a customer request type from a service desk.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required**: Permission to access the service desk.
  * Alternative usage: Servicedesk.Request.Type.getType
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-get
  * @param options Request options.
  */
    async getServicedeskRequestType(options) {
        return this.Servicedesk.Request.Type.getType(options);
    }
    /**
  * This method deletes a customer request type from a service desk, and removes it from all customer requests.
  This only supports classic projects.
  
  **[Permissions](#permissions) required**: Service desk administrator.
  * Alternative usage: Servicedesk.Request.Type.deleteType
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-delete
  * @param options Request options.
  */
    async deleteServicedeskRequestType(options) {
        return this.Servicedesk.Request.Type.deleteType(options);
    }
    /**
  * This method returns the fields for a service desk's customer request type.
  
  Also, the following information about the user's permissions for the request type is returned:
  
   *  `canRaiseOnBehalfOf` returns `true` if the user has permission to raise customer requests on behalf of other customers. Otherwise, returns `false`.
   *  `canAddRequestParticipants` returns `true` if the user can add customer request participants. Otherwise, returns `false`.
  
  **[Permissions](#permissions) required**: Permission to view the Service Desk. However, hidden fields would be visible to only Service desk's Administrator.
  * Alternative usage: Servicedesk.Request.Type.getFields
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-field-get
  * @param options Request options.
  */
    async getServicedeskRequestTypeFields(options) {
        return this.Servicedesk.Request.Type.getFields(options);
    }
    /**
  * This method returns a service desk's customer request type groups. Jira Service Management administrators can arrange the customer request type groups in an arbitrary order for display on the customer portal; the groups are returned in this order.
  
  **[Permissions](#permissions) required**: Permission to view the service desk.
  * Alternative usage: Servicedesk.Request.Type.getTypeGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttypegroup-get
  * @param options Request options.
  */
    async getServicedeskRequestTypeGroups(options) {
        return this.Servicedesk.Request.Type.getTypeGroups(options);
    }
    /**
  * Returns the keys of all properties for a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore the keys of all properties for a request type are also available by calling the Jira Cloud Platform [Get issue type property keys](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-get) endpoint.
  
  **[Permissions](#permissions) required**: The user must have permission to view the request type.
  * Alternative usage: Servicedesk.Request.Type.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-get
  * @param options Request options.
  */
    async getServicedeskRequestTypePropertyKeys(options) {
        return this.Servicedesk.Request.Type.Property.getKeys(options);
    }
    /**
  * Returns the value of the property from a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore also available by calling the Jira Cloud Platform [Get issue type property](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-propertyKey-get) endpoint.
  
  **[Permissions](#permissions) required**: User must have permission to view the request type.
  * Alternative usage: Servicedesk.Request.Type.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-propertykey-get
  * @param options Request options.
  */
    async getServicedeskRequestTypeProperty(options) {
        return this.Servicedesk.Request.Type.Property.getProperty(options);
    }
    /**
  * Sets the value of a request type property. Use this resource to store custom data against a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore can also be set by calling the Jira Cloud Platform [Set issue type property](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-propertyKey-put) endpoint.
  
  **[Permissions](#permissions) required**: Jira project administrator with a Jira Service Management agent license.
  * Alternative usage: Servicedesk.Request.Type.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-propertykey-put
  * @param options Request options.
  */
    async setServicedeskRequestTypeProperty(options) {
        return this.Servicedesk.Request.Type.Property.setProperty(options);
    }
    /**
  * Removes a property from a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore can also be deleted by calling the Jira Cloud Platform [Delete issue type property](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-propertyKey-delete) endpoint.
  
  **[Permissions](#permissions) required**: Jira project administrator with a Jira Service Management agent license.
  * Alternative usage: Servicedesk.Request.Type.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-propertykey-delete
  * @param options Request options.
  */
    async deleteServicedeskRequestTypeProperty(options) {
        return this.Servicedesk.Request.Type.Property.deleteProperty(options);
    }
    /**
  * This method returns all customer requests for the user executing the query.
  
  The returned customer requests are ordered chronologically by the latest activity on each request. For example, the latest status transition or comment.
  
  **[Permissions](#permissions) required**: Permission to access the specified service desk.
  
  **Response limitations**: For customers, the list returned will include request they created (or were created on their behalf) or are participating in only.
  * Alternative usage: Request.getRequests
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-get
  * @param options Request options.
  */
    async getRequests(options) {
        return this.Request.getRequests(options);
    }
    /**
  * This method creates a customer request in a service desk.
  
  The JSON request must include the service desk and customer request type, as well as any fields that are required for the request type. A list of the fields required by a customer request type can be obtained using [servicedesk/\{serviceDeskId\}/requesttype/\{requestTypeId\}/field](#api-servicedesk-serviceDeskId-requesttype-requestTypeId-field-get).
  
  The fields required for a customer request type depend on the user's permissions:
  
   *  `raiseOnBehalfOf` is not available to Users who have the customer permission only.
   *  `requestParticipants` is not available to Users who have the customer permission only or if the feature is turned off for customers.
  
  `requestFieldValues` is a map of Jira field IDs and their values. See [Field input formats](#fieldformats), for details of each field's JSON semantics and the values they can take.
  
  **[Permissions](#permissions) required**: Permission to create requests in the specified service desk.
  * Alternative usage: Request.createRequest
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-post
  * @param options Request options.
  */
    async createRequest(options) {
        return this.Request.createRequest(options);
    }
    /**
  * This method returns a customer request.
  
  **[Permissions](#permissions) required**: Permission to access the specified service desk.
  
  **Response limitations**: For customers, only a request they created, was created on their behalf, or they are participating in will be returned.
  * Alternative usage: Request.getRequest
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-get
  * @param options Request options.
  */
    async getRequest(options) {
        return this.Request.getRequest(options);
    }
    /**
  * This method adds participants to a customer request.
  
  **[Permissions](#permissions) required**: Permission to manage participants on the customer request.
  
  Note, participants can be added when creating a customer request using the [request](#api-request-post) resource, by defining the participants in the `requestParticipants` field.
  * Alternative usage: Request.addParticipants
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-participant-post
  * @param options Request options.
  */
    async addRequestParticipants(options) {
        return this.Request.addParticipants(options);
    }
    /**
  * This method removes participants from a customer request.
  
  **[Permissions](#permissions) required**: Permission to manage participants on the customer request.
  * Alternative usage: Request.removeParticipants
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-participant-delete
  * @param options Request options.
  */
    async removeRequestParticipants(options) {
        return this.Request.removeParticipants(options);
    }
    /**
  * This method returns a list of all the statuses a customer Request has achieved. A status represents the state of an issue in its workflow. An issue can have one active status only. The list returns the status history in chronological order, most recent (current) status first.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.getRequestStatuses
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-status-get
  * @param options Request options.
  */
    async getRequestStatuses(options) {
        return this.Request.getRequestStatuses(options);
    }
    /**
  * This method returns all approvals on a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Approval.getApprovals
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-approval-get
  * @param options Request options.
  */
    async getRequestApprovals(options) {
        return this.Request.Approval.getApprovals(options);
    }
    /**
  * This method returns an approval. Use this method to determine the status of an approval and the list of approvers.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Approval.getApproval
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-approval-approvalid-get
  * @param options Request options.
  */
    async getRequestApproval(options) {
        return this.Request.Approval.getApproval(options);
    }
    /**
  * This method enables a user to **Approve** or **Decline** an approval on a customer request. The approval is assumed to be owned by the user making the call.
  
  **[Permissions](#permissions) required**: User is assigned to the approval request.
  * Alternative usage: Request.Approval.answerApproval
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-approval-approvalid-post
  * @param options Request options.
  */
    async answerRequestApproval(options) {
        return this.Request.Approval.answerApproval(options);
    }
    /**
  * This method returns all the attachments for a customer requests.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers will only get a list of public attachments.
  * Alternative usage: Request.Attachment.getAttachments
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-get
  * @param options Request options.
  */
    async getRequestAttachments(options) {
        return this.Request.Attachment.getAttachments(options);
    }
    /**
  * This method adds one or more temporary files (attached to the request's service desk using [servicedesk/\{serviceDeskId\}/attachTemporaryFile](#api-servicedesk-serviceDeskId-attachTemporaryFile-post)) as attachments to a customer request and set the attachment visibility using the `public` flag. Also, it is possible to include a comment with the attachments.
  
  To get a list of attachments for a comment on the request use [servicedeskapi/request/\{issueIdOrKey\}/comment/\{commentId\}/attachment](#api-request-issueIdOrKey-comment-commentId-attachment-get).
  
  **[Permissions](#permissions) required**: Permission to add an attachment.
  
  **Request limitations**: Customers can set attachments to public visibility only.
  * Alternative usage: Request.Attachment.createAttachments
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-post
  * @param options Request options.
  */
    async createRequestAttachments(options) {
        return this.Request.Attachment.createAttachments(options);
    }
    /**
  * Returns the contents of an attachment.
  
  To return a thumbnail of the attachment, use [servicedeskapi/request/\{issueIdOrKey\}/attachment/\{attachmentId\}/thumbnail](#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-thumbnail-get).
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Request.Attachment.getAttachmentContent
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-get
  * @param options Request options.
  */
    async getRequestAttachmentContent(options) {
        return this.Request.Attachment.getAttachmentContent(options);
    }
    /**
  * Returns the thumbnail of an attachment.
  
  To return the attachment contents, use [servicedeskapi/request/\{issueIdOrKey\}/attachment/\{attachmentId\}](#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-get).
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Request.Attachment.getAttachmentThumbnail
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-thumbnail-get
  * @param options Request options.
  */
    async getRequestAttachmentThumbnail(options) {
        return this.Request.Attachment.getAttachmentThumbnail(options);
    }
    /**
  * This method returns all comments on a customer request. No permissions error is provided if, for example, the user doesn't have access to the service desk or request, the method simply returns an empty response.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers are returned public comments only.
  * Alternative usage: Request.Comment.getComments
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-get
  * @param options Request options.
  */
    async getRequestComments(options) {
        return this.Request.Comment.getComments(options);
    }
    /**
  * This method creates a public or private (internal) comment on a customer request, with the comment visibility set by `public`. The user recorded as the author of the comment.
  
  **[Permissions](#permissions) required**: User has Add Comments permission.
  
  **Request limitations**: Customers can set comments to public visibility only.
  * Alternative usage: Request.Comment.createComment
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-post
  * @param options Request options.
  */
    async createRequestComment(options) {
        return this.Request.Comment.createComment(options);
    }
    /**
  * This method returns details of a customer request's comment.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers can only view public comments on requests where they are the reporter or a participant whereas agents can see both internal and public comments.
  * Alternative usage: Request.Comment.getComment
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-commentid-get
  * @param options Request options.
  */
    async getRequestComment(options) {
        return this.Request.Comment.getComment(options);
    }
    /**
  * This method returns the attachments referenced in a comment.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers can only view public comments, and retrieve their attachments, on requests where they are the reporter or a participant whereas agents can see both internal and public comments.
  * Alternative usage: Request.Comment.getCommentAttachments
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-commentid-attachment-get
  * @param options Request options.
  */
    async getRequestCommentAttachments(options) {
        return this.Request.Comment.getCommentAttachments(options);
    }
    /**
  * This method returns the notification subscription status of the user making the request. Use this method to determine if the user is subscribed to a customer request's notifications.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Notification.getNotificationStatus
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-notification-get
  * @param options Request options.
  */
    async getRequestNotificationStatus(options) {
        return this.Request.Notification.getNotificationStatus(options);
    }
    /**
  * This method subscribes the user to receiving notifications from a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Notification.subscribeToRequest
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-notification-put
  * @param options Request options.
  */
    async subscribeToRequest(options) {
        return this.Request.Notification.subscribeToRequest(options);
    }
    /**
  * This method unsubscribes the user from notifications from a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Notification.unsubscribeFromRequest
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-notification-delete
  * @param options Request options.
  */
    async unsubscribeFromRequest(options) {
        return this.Request.Notification.unsubscribeFromRequest(options);
    }
    /**
  * This method returns a list of all the participants on a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Participant.getParticipants
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-participant-get
  * @param options Request options.
  */
    async getRequestParticipants(options) {
        return this.Request.Participant.getParticipants(options);
    }
    /**
  * This method returns all the SLA records on a customer request. A customer request can have zero or more SLAs. Each SLA can have recordings for zero or more "completed cycles" and zero or 1 "ongoing cycle". Each cycle includes information on when it started and stopped, and whether it breached the SLA goal.
  
  **[Permissions](#permissions) required**: Agent for the Service Desk containing the queried customer request.
  * Alternative usage: Request.SLA.getSLAs
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-sla-get
  * @param options Request options.
  */
    async getRequestSlAs(options) {
        return this.Request.SLA.getSlAs(options);
    }
    /**
  * This method returns the details for an SLA on a customer request.
  
  **[Permissions](#permissions) required**: Agent for the Service Desk containing the queried customer request.
  * Alternative usage: Request.SLA.getSLA
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-sla-slametricid-get
  * @param options Request options.
  */
    async getRequestSla(options) {
        return this.Request.SLA.getSla(options);
    }
    /**
  * This method returns a list of transitions, the workflow processes that moves a customer request from one status to another, that the user can perform on a request. Use this method to provide a user with a list if the actions they can take on a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Alternative usage: Request.Transition.getTransitions
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-transition-get
  * @param options Request options.
  */
    async getRequestTransitions(options) {
        return this.Request.Transition.getTransitions(options);
    }
    /**
  * This method performs a customer transition for a given request and transition. An optional comment can be included to provide a reason for the transition.
  
  **[Permissions](#permissions) required**: The user must be able to view the request and have the Transition Issues permission. If a comment is passed the user must have the Add Comments permission.
  * Alternative usage: Request.Transition.performTransition
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-transition-post
  * @param options Request options.
  */
    async performRequestTransition(options) {
        return this.Request.Transition.performTransition(options);
    }
    /**
  * This method retrieves a feedback of a request using it's `requestKey` or `requestId`
  
  **[Permissions](#permissions) required**: User has view request permissions.
  * Alternative usage: Request.Feedback.getFeedback
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-requestidorkey-feedback-get
  * @param options Request options.
  */
    async getRequestFeedback(options) {
        return this.Request.Feedback.getFeedback(options);
    }
    /**
  * This method adds a feedback on an request using it's `requestKey` or `requestId`
  
  **[Permissions](#permissions) required**: User must be the reporter or an Atlassian Connect app.
  * Alternative usage: Request.Feedback.postFeedback
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-requestidorkey-feedback-post
  * @param options Request options.
  */
    async postRequestFeedback(options) {
        return this.Request.Feedback.postFeedback(options);
    }
    /**
  * This method deletes the feedback of request using it's `requestKey` or `requestId`
  
  **[Permissions](#permissions) required**: User must be the reporter or an Atlassian Connect app.
  * Alternative usage: Request.Feedback.deleteFeedback
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-requestidorkey-feedback-delete
  * @param options Request options.
  */
    async deleteRequestFeedback(options) {
        return this.Request.Feedback.deleteFeedback(options);
    }
    /**
  * This method returns all customer request types used in the Jira Service Management instance, optionally filtered by a query string.
  
  Use [servicedeskapi/servicedesk/\{serviceDeskId\}/requesttype](#api-servicedesk-serviceDeskId-requesttype-get) to find the customer request types supported by a specific service desk.
  
  The returned list of customer request types can be filtered using the `query` parameter. The parameter is matched against the customer request types' `name` or `description`. For example, searching for "Install", "Inst", "Equi", or "Equipment" will match a customer request type with the *name* "Equipment Installation Request".
  
  **[Permissions](#permissions) required**: Any
  * Alternative usage: Request.Type.getTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-requesttype/#api-rest-servicedeskapi-requesttype-get
  * @param options Request options.
  */
    async getRequestTypes(options) {
        return this.Request.Type.getTypes(options);
    }
}
class CustomerGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method adds a customer to the Jira Service Management instance by passing a JSON file including an email address and display name. The display name does not need to be unique. The record's identifiers, `name` and `key`, are automatically generated from the request details.
  
  **[Permissions](#permissions) required**: Jira Administrator Global permission
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-customer/#api-rest-servicedeskapi-customer-post
  * @param options Request options.
  */
    async createCustomer(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/servicedeskapi/customer`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class InfoGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method retrieves information about the Jira Service Management instance such as software version, builds, and related links.
  
  **[Permissions](#permissions) required**: None, the user does not need to be logged in.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-info/#api-rest-servicedeskapi-info-get
  * @param options Request options.
  */
    async getInfo(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/servicedeskapi/info`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class AssetsGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of Assets workspace IDs. Include a workspace ID in the path to access the [Assets REST APIs](https://developer.atlassian.com/cloud/assets/rest).
  
  **[Permissions](#permissions) required**: Any
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-assets/#api-rest-servicedeskapi-assets-workspace-get
  * @param options Request options.
  */
    async getWorkspaces(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/assets/workspace`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class KnowledgebaseGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns articles which match the given query string across all service desks.
  
  **[Permissions](#permissions) required**: Permission to access the [customer portal](https://confluence.atlassian.com/servicedeskcloud/configuring-the-customer-portal-732528918.html).
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-knowledgebase/#api-rest-servicedeskapi-knowledgebase-article-get
  * @param options Request options.
  */
    async getArticles(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/knowledgebase/article`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class OrganizationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new OrganizationPropertyGroup(implementation, this.getGlobalErrorStrategy);
        this.User = new OrganizationUserGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * This method returns a list of organizations in the Jira Service Management instance. Use this method when you want to present a list of organizations or want to locate an organization by name.
  
  **[Permissions](#permissions) required**: Any. However, to fetch organizations based on `accountId` the user must have a Service Desk agent license.
  
  **Response limitations**: If the user is a customer, only those organizations of which the customer is a member are listed.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-get
  * @param options Request options.
  */
    async getOrganizations(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/organization`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method creates an organization by passing the name of the organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent. Note: Permission to create organizations can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-post
  * @param options Request options.
  */
    async createOrganization(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/servicedeskapi/organization`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns details of an organization. Use this method to get organization details whenever your application component is passed an organization ID but needs to display other organization details.
  
  **[Permissions](#permissions) required**: Any
  
  **Response limitations**: Customers can only retrieve organization of which they are members.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-get
  * @param options Request options.
  */
    async getOrganization(options) {
        const { headers, errorStrategy, organizationId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method deletes an organization. Note that the organization is deleted regardless of other associations it may have. For example, associations with service desks.
  
  **[Permissions](#permissions) required**: Jira administrator.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-delete
  * @param options Request options.
  */
    async deleteOrganization(options) {
        const { headers, errorStrategy, organizationId } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class OrganizationPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the keys of all properties for an organization. Use this resource when you need to find out what additional properties items have been added to an organization.
  
  **[Permissions](#permissions) required**: Any
  
  **Response limitations**: Customers can only access properties of organizations of which they are members.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-get
  * @param options Request options.
  */
    async getKeys(options) {
        const { headers, errorStrategy, organizationId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/property`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the value of a property from an organization. Use this method to obtain the JSON content for an organization's property.
  
  **[Permissions](#permissions) required**: Any
  
  **Response limitations**: Customers can only access properties of organizations of which they are members.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, organizationId, propertyKey } = options;
        const request = new Request("GET", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/property/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of a property for an organization. Use this resource to store custom data against an organization.
  
  **[Permissions](#permissions) required**: Service Desk Administrator or Agent.
  
  Note: Permission to manage organizations can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { headers, errorStrategy, organizationId, propertyKey } = options;
        const request = new Request("PUT", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/property/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a property from an organization.
  
  **[Permissions](#permissions) required**: Service Desk Administrator or Agent.
  
  Note: Permission to manage organizations can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-property-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, organizationId, propertyKey } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/property/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class OrganizationUserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns all the users associated with an organization. Use this method where you want to provide a list of users for an organization or determine if a user is associated with an organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-user-get
  * @param options Request options.
  */
    async getUsers(options) {
        const { headers, errorStrategy, organizationId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method adds users to an organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent. Note: Permission to add users to an organization can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-user-post
  * @param options Request options.
  */
    async addUser(options) {
        const { body, headers, errorStrategy, organizationId } = options;
        const request = new Request("POST", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/user`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method removes users from an organization.
  
  **[Permissions](#permissions) required**: Service desk administrator or agent. Note: Permission to delete users from an organization can be switched to users with the Jira administrator permission, using the **[Organization management](https://confluence.atlassian.com/servicedeskcloud/setting-up-service-desk-users-732528877.html#Settingupservicedeskusers-manageorgsManageorganizations)** feature.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-organization-organizationid-user-delete
  * @param options Request options.
  */
    async removeUser(options) {
        const { body, headers, errorStrategy, organizationId } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/user`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Organization = new ServicedeskOrganizationGroup(implementation, this.getGlobalErrorStrategy);
        this.Customer = new ServicedeskCustomerGroup(implementation, this.getGlobalErrorStrategy);
        this.Knowledgebase = new ServicedeskKnowledgebaseGroup(implementation, this.getGlobalErrorStrategy);
        this.Queue = new ServicedeskQueueGroup(implementation, this.getGlobalErrorStrategy);
        this.Request = new ServicedeskRequestGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * This method returns all the service desks in the Jira Service Management instance that the user has permission to access. Use this method where you need a list of service desks or need to locate a service desk by name or keyword.
  
  **[Permissions](#permissions) required**: Any
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-get
  * @param options Request options.
  */
    async getServicedesks(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns a service desk. Use this method to get service desk details whenever your application component is passed a service desk ID but needs to display other service desk details.
  
  **[Permissions](#permissions) required**: Permission to access the Service Desk. For example, being the Service Desk's Administrator or one of its Agents or Users.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-get
  * @param options Request options.
  */
    async getServicedesk(options) {
        const { headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method adds one or more temporary attachments to a service desk, which can then be permanently attached to a customer request using [servicedeskapi/request/\{issueIdOrKey\}/attachment](#api-request-issueIdOrKey-attachment-post).
  
  **Note**: It is possible for a service desk administrator to turn off the ability to add attachments to a service desk.
  
  This method expects a multipart request. The media-type multipart/form-data is defined in RFC 1867. Most client libraries have classes that make dealing with multipart posts simple. For instance, in Java the Apache HTTP Components library provides [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html).
  
  Because this method accepts multipart/form-data, it has XSRF protection on it. This means you must submit a header of X-Atlassian-Token: no-check with the request or it will be blocked.
  
  The name of the multipart/form-data parameter that contains the attachments must be `file`.
  
  For example, to upload a file called `myfile.txt` in the Service Desk with ID 10001 use
  
      curl -D- -u customer:customer -X POST -H "X-ExperimentalApi: opt-in" -H "X-Atlassian-Token: no-check" -F "file=@myfile.txt" https://your-domain.atlassian.net/rest/servicedeskapi/servicedesk/10001/attachTemporaryFile
  
  **[Permissions](#permissions) required**: Permission to add attachments in this Service Desk.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-attachtemporaryfile-post
  * @param options Request options.
  */
    async addTemporaryFilesToServicedesk(options) {
        const { headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("POST", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/attachTemporaryFile`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskOrganizationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns a list of all organizations associated with a service desk.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-servicedesk-servicedeskid-organization-get
  * @param options Request options.
  */
    async getOrganizations(options) {
        const { headers, errorStrategy, serviceDeskId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/organization`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method adds an organization to a service desk. If the organization ID is already associated with the service desk, no change is made and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-servicedesk-servicedeskid-organization-post
  * @param options Request options.
  */
    async addOrganization(options) {
        const { body, headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("POST", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/organization`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method removes an organization from a service desk. If the organization ID does not match an organization associated with the service desk, no change is made and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-organization/#api-rest-servicedeskapi-servicedesk-servicedeskid-organization-delete
  * @param options Request options.
  */
    async removeOrganization(options) {
        const { body, headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/organization`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskCustomerGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns a list of the customers on a service desk.
  
  The returned list of customers can be filtered using the `query` parameter. The parameter is matched against customers' `displayName`, `name`, or `email`. For example, searching for "John", "Jo", "Smi", or "Smith" will match a user with display name "John Smith".
  
  **[Permissions](#permissions) required**: Permission to view this Service Desk's customers.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-customer-get
  * @param options Request options.
  */
    async getCustomers(options) {
        const { headers, errorStrategy, serviceDeskId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/customer`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds one or more customers to a service desk. If any of the passed customers are associated with the service desk, no changes will be made for those customers and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Service desk administrator
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-customer-post
  * @param options Request options.
  */
    async addCustomers(options) {
        const { body, headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("POST", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/customer`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method removes one or more customers from a service desk. The service desk must have closed access. If any of the passed customers are not associated with the service desk, no changes will be made for those customers and the resource returns a 204 success code.
  
  **[Permissions](#permissions) required**: Services desk administrator
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-customer-delete
  * @param options Request options.
  */
    async removeCustomers(options) {
        const { body, headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/customer`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskKnowledgebaseGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns articles which match the given query and belong to the knowledge base linked to the service desk.
  
  **[Permissions](#permissions) required**: Permission to access the service desk.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-knowledgebase-article-get
  * @param options Request options.
  */
    async getArticles(options) {
        const { headers, errorStrategy, serviceDeskId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/knowledgebase/article`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskQueueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns the queues in a service desk. To include a customer request count for each queue (in the `issueCount` field) in the response, set the query parameter `includeCount` to true (its default is false).
  
  **[Permissions](#permissions) required**: service desk's Agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-queue-get
  * @param options Request options.
  */
    async getQueues(options) {
        const { headers, errorStrategy, serviceDeskId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns a specific queues in a service desk. To include a customer request count for the queue (in the `issueCount` field) in the response, set the query parameter `includeCount` to true (its default is false).
  
  **[Permissions](#permissions) required**: service desk's Agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-queue-queueid-get
  * @param options Request options.
  */
    async getQueue(options) {
        const { headers, errorStrategy, serviceDeskId, queueId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/${encodeURIComponent(queueId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns the customer requests in a queue. Only fields that the queue is configured to show are returned. For example, if a queue is configured to show description and due date, then only those two fields are returned for each customer request in the queue.
  
  **[Permissions](#permissions) required**: Service desk's agent.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-queue-queueid-issue-get
  * @param options Request options.
  */
    async getIssuesInQueue(options) {
        const { headers, errorStrategy, serviceDeskId, queueId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/${encodeURIComponent(queueId)}/issue`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskRequestGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Type = new ServicedeskRequestTypeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ServicedeskRequestTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new ServicedeskRequestTypePropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * This method returns all customer request types from a service desk. There are two parameters for filtering the returned list:
  
   *  `groupId` which filters the results to items in the customer request type group.
   *  `searchQuery` which is matched against request types' `name` or `description`. For example, the strings "Install", "Inst", "Equi", or "Equipment" will match a request type with the *name* "Equipment Installation Request".
  
  **[Permissions](#permissions) required**: Permission to access the service desk.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-get
  * @param options Request options.
  */
    async getTypes(options) {
        const { headers, errorStrategy, serviceDeskId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method enables a customer request type to be added to a service desk based on an issue type. Note that not all customer request type fields can be specified in the request and these fields are given the following default values:
  
   *  Request type icon is given the headset icon.
   *  Request type groups is left empty, which means this customer request type will not be visible on the [customer portal](https://confluence.atlassian.com/servicedeskcloud/configuring-the-customer-portal-732528918.html).
   *  Request type status mapping is left empty, so the request type has no custom status mapping but inherits the status map from the issue type upon which it is based.
   *  Request type field mapping is set to show the required fields as specified by the issue type used to create the customer request type.
  
    
  These fields can be updated by a service desk administrator using the **Request types** option in **Project settings**.
  Request Types are created in next-gen projects by creating Issue Types. Please use the Jira Cloud Platform Create issue type endpoint instead.
  
  **[Permissions](#permissions) required**: Service desk's administrator
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-post
  * @param options Request options.
  */
    async createType(options) {
        const { body, headers, errorStrategy, serviceDeskId } = options;
        const request = new Request("POST", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns a customer request type from a service desk.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required**: Permission to access the service desk.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-get
  * @param options Request options.
  */
    async getType(options) {
        const { headers, errorStrategy, serviceDeskId, requestTypeId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method deletes a customer request type from a service desk, and removes it from all customer requests.
  This only supports classic projects.
  
  **[Permissions](#permissions) required**: Service desk administrator.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-delete
  * @param options Request options.
  */
    async deleteType(options) {
        const { headers, errorStrategy, serviceDeskId, requestTypeId } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns the fields for a service desk's customer request type.
  
  Also, the following information about the user's permissions for the request type is returned:
  
   *  `canRaiseOnBehalfOf` returns `true` if the user has permission to raise customer requests on behalf of other customers. Otherwise, returns `false`.
   *  `canAddRequestParticipants` returns `true` if the user can add customer request participants. Otherwise, returns `false`.
  
  **[Permissions](#permissions) required**: Permission to view the Service Desk. However, hidden fields would be visible to only Service desk's Administrator.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-field-get
  * @param options Request options.
  */
    async getFields(options) {
        const { headers, errorStrategy, serviceDeskId, requestTypeId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}/field`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns a service desk's customer request type groups. Jira Service Management administrators can arrange the customer request type groups in an arbitrary order for display on the customer portal; the groups are returned in this order.
  
  **[Permissions](#permissions) required**: Permission to view the service desk.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttypegroup-get
  * @param options Request options.
  */
    async getTypeGroups(options) {
        const { headers, errorStrategy, serviceDeskId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttypegroup`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskRequestTypePropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the keys of all properties for a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore the keys of all properties for a request type are also available by calling the Jira Cloud Platform [Get issue type property keys](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-get) endpoint.
  
  **[Permissions](#permissions) required**: The user must have permission to view the request type.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-get
  * @param options Request options.
  */
    async getKeys(options) {
        const { headers, errorStrategy, requestTypeId, serviceDeskId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}/property`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the value of the property from a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore also available by calling the Jira Cloud Platform [Get issue type property](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-propertyKey-get) endpoint.
  
  **[Permissions](#permissions) required**: User must have permission to view the request type.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, serviceDeskId, requestTypeId, propertyKey } = options;
        const request = new Request("GET", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}/property/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of a request type property. Use this resource to store custom data against a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore can also be set by calling the Jira Cloud Platform [Set issue type property](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-propertyKey-put) endpoint.
  
  **[Permissions](#permissions) required**: Jira project administrator with a Jira Service Management agent license.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { headers, errorStrategy, serviceDeskId, requestTypeId, propertyKey } = options;
        const request = new Request("PUT", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}/property/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a property from a request type.
  
  Properties for a Request Type in next-gen are stored as Issue Type properties and therefore can also be deleted by calling the Jira Cloud Platform [Delete issue type property](https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-issueTypeId-properties-propertyKey-delete) endpoint.
  
  **[Permissions](#permissions) required**: Jira project administrator with a Jira Service Management agent license.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-servicedesk/#api-rest-servicedeskapi-servicedesk-servicedeskid-requesttype-requesttypeid-property-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, serviceDeskId, requestTypeId, propertyKey } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}/property/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Approval = new RequestApprovalGroup(implementation, this.getGlobalErrorStrategy);
        this.Attachment = new RequestAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new RequestCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Notification = new RequestNotificationGroup(implementation, this.getGlobalErrorStrategy);
        this.Participant = new RequestParticipantGroup(implementation, this.getGlobalErrorStrategy);
        this.SLA = new RequestSLAGroup(implementation, this.getGlobalErrorStrategy);
        this.Transition = new RequestTransitionGroup(implementation, this.getGlobalErrorStrategy);
        this.Feedback = new RequestFeedbackGroup(implementation, this.getGlobalErrorStrategy);
        this.Type = new RequestTypeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * This method returns all customer requests for the user executing the query.
  
  The returned customer requests are ordered chronologically by the latest activity on each request. For example, the latest status transition or comment.
  
  **[Permissions](#permissions) required**: Permission to access the specified service desk.
  
  **Response limitations**: For customers, the list returned will include request they created (or were created on their behalf) or are participating in only.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-get
  * @param options Request options.
  */
    async getRequests(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method creates a customer request in a service desk.
  
  The JSON request must include the service desk and customer request type, as well as any fields that are required for the request type. A list of the fields required by a customer request type can be obtained using [servicedesk/\{serviceDeskId\}/requesttype/\{requestTypeId\}/field](#api-servicedesk-serviceDeskId-requesttype-requestTypeId-field-get).
  
  The fields required for a customer request type depend on the user's permissions:
  
   *  `raiseOnBehalfOf` is not available to Users who have the customer permission only.
   *  `requestParticipants` is not available to Users who have the customer permission only or if the feature is turned off for customers.
  
  `requestFieldValues` is a map of Jira field IDs and their values. See [Field input formats](#fieldformats), for details of each field's JSON semantics and the values they can take.
  
  **[Permissions](#permissions) required**: Permission to create requests in the specified service desk.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-post
  * @param options Request options.
  */
    async createRequest(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns a customer request.
  
  **[Permissions](#permissions) required**: Permission to access the specified service desk.
  
  **Response limitations**: For customers, only a request they created, was created on their behalf, or they are participating in will be returned.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-get
  * @param options Request options.
  */
    async getRequest(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method adds participants to a customer request.
  
  **[Permissions](#permissions) required**: Permission to manage participants on the customer request.
  
  Note, participants can be added when creating a customer request using the [request](#api-request-post) resource, by defining the participants in the `requestParticipants` field.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-participant-post
  * @param options Request options.
  */
    async addParticipants(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/participant`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method removes participants from a customer request.
  
  **[Permissions](#permissions) required**: Permission to manage participants on the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-participant-delete
  * @param options Request options.
  */
    async removeParticipants(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/participant`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns a list of all the statuses a customer Request has achieved. A status represents the state of an issue in its workflow. An issue can have one active status only. The list returns the status history in chronological order, most recent (current) status first.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-status-get
  * @param options Request options.
  */
    async getRequestStatuses(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/status`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestApprovalGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns all approvals on a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-approval-get
  * @param options Request options.
  */
    async getApprovals(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/approval`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns an approval. Use this method to determine the status of an approval and the list of approvers.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-approval-approvalid-get
  * @param options Request options.
  */
    async getApproval(options) {
        const { headers, errorStrategy, issueIdOrKey, approvalId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/approval/${encodeURIComponent(approvalId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method enables a user to **Approve** or **Decline** an approval on a customer request. The approval is assumed to be owned by the user making the call.
  
  **[Permissions](#permissions) required**: User is assigned to the approval request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-approval-approvalid-post
  * @param options Request options.
  */
    async answerApproval(options) {
        const { body, headers, errorStrategy, issueIdOrKey, approvalId } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/approval/${encodeURIComponent(approvalId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns all the attachments for a customer requests.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers will only get a list of public attachments.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-get
  * @param options Request options.
  */
    async getAttachments(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/attachment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method adds one or more temporary files (attached to the request's service desk using [servicedesk/\{serviceDeskId\}/attachTemporaryFile](#api-servicedesk-serviceDeskId-attachTemporaryFile-post)) as attachments to a customer request and set the attachment visibility using the `public` flag. Also, it is possible to include a comment with the attachments.
  
  To get a list of attachments for a comment on the request use [servicedeskapi/request/\{issueIdOrKey\}/comment/\{commentId\}/attachment](#api-request-issueIdOrKey-comment-commentId-attachment-get).
  
  **[Permissions](#permissions) required**: Permission to add an attachment.
  
  **Request limitations**: Customers can set attachments to public visibility only.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-post
  * @param options Request options.
  */
    async createAttachments(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/attachment`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the contents of an attachment.
  
  To return a thumbnail of the attachment, use [servicedeskapi/request/\{issueIdOrKey\}/attachment/\{attachmentId\}/thumbnail](#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-thumbnail-get).
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-get
  * @param options Request options.
  */
    async getAttachmentContent(options) {
        const { headers, errorStrategy, issueIdOrKey, attachmentId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/attachment/${encodeURIComponent(attachmentId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the thumbnail of an attachment.
  
  To return the attachment contents, use [servicedeskapi/request/\{issueIdOrKey\}/attachment/\{attachmentId\}](#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-get).
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-attachment-attachmentid-thumbnail-get
  * @param options Request options.
  */
    async getAttachmentThumbnail(options) {
        const { headers, errorStrategy, issueIdOrKey, attachmentId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/attachment/${encodeURIComponent(attachmentId)}/thumbnail`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns all comments on a customer request. No permissions error is provided if, for example, the user doesn't have access to the service desk or request, the method simply returns an empty response.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers are returned public comments only.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method creates a public or private (internal) comment on a customer request, with the comment visibility set by `public`. The user recorded as the author of the comment.
  
  **[Permissions](#permissions) required**: User has Add Comments permission.
  
  **Request limitations**: Customers can set comments to public visibility only.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-post
  * @param options Request options.
  */
    async createComment(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns details of a customer request's comment.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers can only view public comments on requests where they are the reporter or a participant whereas agents can see both internal and public comments.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-commentid-get
  * @param options Request options.
  */
    async getComment(options) {
        const { headers, errorStrategy, issueIdOrKey, commentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment/${encodeURIComponent(commentId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns the attachments referenced in a comment.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  
  **Response limitations**: Customers can only view public comments, and retrieve their attachments, on requests where they are the reporter or a participant whereas agents can see both internal and public comments.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-comment-commentid-attachment-get
  * @param options Request options.
  */
    async getCommentAttachments(options) {
        const { headers, errorStrategy, issueIdOrKey, commentId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment/${encodeURIComponent(commentId)}/attachment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestNotificationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns the notification subscription status of the user making the request. Use this method to determine if the user is subscribed to a customer request's notifications.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-notification-get
  * @param options Request options.
  */
    async getNotificationStatus(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("GET", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/notification`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method subscribes the user to receiving notifications from a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-notification-put
  * @param options Request options.
  */
    async subscribeToRequest(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("PUT", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/notification`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method unsubscribes the user from notifications from a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-notification-delete
  * @param options Request options.
  */
    async unsubscribeFromRequest(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/notification`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestParticipantGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns a list of all the participants on a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-participant-get
  * @param options Request options.
  */
    async getParticipants(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/participant`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestSLAGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns all the SLA records on a customer request. A customer request can have zero or more SLAs. Each SLA can have recordings for zero or more "completed cycles" and zero or 1 "ongoing cycle". Each cycle includes information on when it started and stopped, and whether it breached the SLA goal.
  
  **[Permissions](#permissions) required**: Agent for the Service Desk containing the queried customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-sla-get
  * @param options Request options.
  */
    async getSlAs(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/sla`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method returns the details for an SLA on a customer request.
  
  **[Permissions](#permissions) required**: Agent for the Service Desk containing the queried customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-sla-slametricid-get
  * @param options Request options.
  */
    async getSla(options) {
        const { headers, errorStrategy, issueIdOrKey, slaMetricId } = options;
        const request = new Request("GET", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/sla/${encodeURIComponent(slaMetricId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestTransitionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns a list of transitions, the workflow processes that moves a customer request from one status to another, that the user can perform on a request. Use this method to provide a user with a list if the actions they can take on a customer request.
  
  **[Permissions](#permissions) required**: Permission to view the customer request.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-transition-get
  * @param options Request options.
  */
    async getTransitions(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/transition`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method performs a customer transition for a given request and transition. An optional comment can be included to provide a reason for the transition.
  
  **[Permissions](#permissions) required**: The user must be able to view the request and have the Transition Issues permission. If a comment is passed the user must have the Add Comments permission.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-issueidorkey-transition-post
  * @param options Request options.
  */
    async performTransition(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/transition`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestFeedbackGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method retrieves a feedback of a request using it's `requestKey` or `requestId`
  
  **[Permissions](#permissions) required**: User has view request permissions.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-requestidorkey-feedback-get
  * @param options Request options.
  */
    async getFeedback(options) {
        const { headers, errorStrategy, requestIdOrKey } = options;
        const request = new Request("GET", `/rest/servicedeskapi/request/${encodeURIComponent(requestIdOrKey)}/feedback`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method adds a feedback on an request using it's `requestKey` or `requestId`
  
  **[Permissions](#permissions) required**: User must be the reporter or an Atlassian Connect app.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-requestidorkey-feedback-post
  * @param options Request options.
  */
    async postFeedback(options) {
        const { body, headers, errorStrategy, requestIdOrKey } = options;
        const request = new Request("POST", `/rest/servicedeskapi/request/${encodeURIComponent(requestIdOrKey)}/feedback`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * This method deletes the feedback of request using it's `requestKey` or `requestId`
  
  **[Permissions](#permissions) required**: User must be the reporter or an Atlassian Connect app.
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-request/#api-rest-servicedeskapi-request-requestidorkey-feedback-delete
  * @param options Request options.
  */
    async deleteFeedback(options) {
        const { headers, errorStrategy, requestIdOrKey } = options;
        const request = new Request("DELETE", `/rest/servicedeskapi/request/${encodeURIComponent(requestIdOrKey)}/feedback`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * This method returns all customer request types used in the Jira Service Management instance, optionally filtered by a query string.
  
  Use [servicedeskapi/servicedesk/\{serviceDeskId\}/requesttype](#api-servicedesk-serviceDeskId-requesttype-get) to find the customer request types supported by a specific service desk.
  
  The returned list of customer request types can be filtered using the `query` parameter. The parameter is matched against the customer request types' `name` or `description`. For example, searching for "Install", "Inst", "Equi", or "Equipment" will match a customer request type with the *name* "Equipment Installation Request".
  
  **[Permissions](#permissions) required**: Any
  * Documentation: https://developer.atlassian.com/cloud/jira/service-desk/rest/api-group-requesttype/#api-rest-servicedeskapi-requesttype-get
  * @param options Request options.
  */
    async getTypes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/servicedeskapi/requesttype`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map